==> engine-pi-demos-0.18.0-sources.jar: de/pirckheimer_gymnasium/engine_pi_demos/event/PerodicTaskDemo.java <==
package de.pirckheimer_gymnasium.engine_pi_demos.event;

import java.awt.event.KeyEvent;

import de.pirckheimer_gymnasium.engine_pi.Game;
import de.pirckheimer_gymnasium.engine_pi.Scene;
import de.pirckheimer_gymnasium.engine_pi.actor.Text;
import de.pirckheimer_gymnasium.engine_pi.event.PeriodicTask;

public class PerodicTaskDemo extends Scene
{
    private PeriodicTask task;

    public PerodicTaskDemo()
    {
        add(new CounterText());
    }

    private class CounterText extends Text
    {
        private int counter = 0;

        public CounterText()
        {
            super("0", 2);
            setCenter(0, 0);
            start();
            addKeyStrokeListener((e) -> {
                if (e.getKeyCode() == KeyEvent.VK_SPACE)
                {
                    if (task == null)
                    {
                        start();
                    }
                    else
                    {
                        stop();
                    }
                }
                else if (e.getKeyCode() == KeyEvent.VK_P)
                {
                    if (task.isPaused)
                    {
                        task.resume();
                    }
                    else
                    {
                        task.pause();
                    }
                }
            });
        }

        public void start()
        {
            task = new PeriodicTask(0.1, () -> {
                counter++;
                setContent(String.valueOf(counter));
            });
            addFrameUpdateListener(task);
        }

        public void stop()
        {
            task.unregister();
            task = null;
        }
    }

    public static void main(String[] args)
    {
        Game.start(400, 200, new PerodicTaskDemo());
    }
}

==> engine-pi-demos-0.19.0-sources.jar: de/pirckheimer_gymnasium/engine_pi_demos/event/PerodicTaskDemo.java <==
package de.pirckheimer_gymnasium.engine_pi_demos.event;

import java.awt.event.KeyEvent;

import de.pirckheimer_gymnasium.engine_pi.Game;
import de.pirckheimer_gymnasium.engine_pi.Scene;
import de.pirckheimer_gymnasium.engine_pi.actor.Text;
import de.pirckheimer_gymnasium.engine_pi.event.PeriodicTask;

/**
 * Demonstriert die Klasse
 * {@link de.pirckheimer_gymnasium.engine_pi.event.PeriodicTask}.
 *
 * <p>
 * Im Spielfenster wird eine Zahl hochgezählt. Über die Taste <b>P</b> kann die
 * periodische Aufgabe pausiert oder fortgesetzt werden. Über die
 * <b>Leertaste</b> kann die periodische Aufgabe gestoppt, was jedoch mit einer
 * <b>Fehlermeldung</b> (so gewollt) fehlschlägt.
 * </p>
 */
public class PerodicTaskDemo extends Scene
{
    private PeriodicTask task;

    public PerodicTaskDemo()
    {
        setBackgroundColor("white");
        add(new CounterText());
    }

    private class CounterText extends Text
    {
        private int counter = 0;

        public CounterText()
        {
            super("0", 2);
            setCenter(0, 0);
            start();
            addKeyStrokeListener((e) -> {
                if (e.getKeyCode() == KeyEvent.VK_SPACE)
                {
                    if (task == null)
                    {
                        start();
                    }
                    else
                    {
                        stop();
                    }
                }
                else if (e.getKeyCode() == KeyEvent.VK_P)
                {
                    if (task.isPaused)
                    {
                        task.resume();
                    }
                    else
                    {
                        task.pause();
                    }
                }
            });
        }

        public void start()
        {
            task = new PeriodicTask(0.1, () -> {
                counter++;
                setContent(counter);
            });
            addFrameUpdateListener(task);
        }

        public void stop()
        {
            task.unregister();
            task = null;
        }
    }

    public static void main(String[] args)
    {
        Game.start(400, 200, new PerodicTaskDemo());
    }
}
